@@ -81,7 +81,7 @@ def _readline(fd):
     return line
 
 
-def main(files, ignore_exceptions=[], out=sys.stdout):
+def main(files, ignore_exceptions=[], out=sys.stdout, err=sys.stderr):
     tracebacks = {}
     for file_ in files:
         with getfile(file_, 'rb') as (fd, filename):
@@ -124,10 +124,10 @@ def main(files, ignore_exceptions=[], out=sys.stdout):
         for e in ignore_exceptions:
             ignore = any(e.ignore_exception.search(exc) for exc in exceptions) and (not e.ignore_traceback or any(tb_pattern.search(traceback) for tb_pattern in e.ignore_traceback))
             if ignore:
-                print('', file=out)
+                print('', file=err)
                 for bug in e.bugs:
-                    print('https://forge.univention.org/bugzilla/show_bug.cgi?id=%d' % (bug,), file=out)
-                print('Ignoring %s ' % (e.ignore_exception.pattern,), file=out)
+                    print('https://forge.univention.org/bugzilla/show_bug.cgi?id=%d' % (bug,), file=err)
+                print('Ignoring %s ' % (e.ignore_exception.pattern,), file=err)
                 break
         if ignore:
             continue
@@ -171,6 +171,7 @@ COMMON_EXCEPTIONS = (
     # # Errors from UCS Jenkins runs:
     E(r'^(ldap\.)?SERVER_DOWN: .*'),
     E(r'^(ldap\.)?NO_SUCH_OBJECT: .*'),
+    E('^keycloak.exceptions.KeycloakAuthenticationError:.*invalid_grant', ['/usr/sbin/univention-keycloak'], 58369),
     # E(r'^(univention\.admin\.uexceptions\.)?objectExists: .*', [re.compile('_create.*self.lo.add', re.M | re.S)]),
     # E('^%s.*logo' % re.escape("IOError: [Errno 2] No such file or directory: u'/var/cache/univention-appcenter/"), [re.compile('%s.*shutil' % re.escape('<stdin>'), re.M | re.S)]),
     # E("INSUFFICIENT_ACCESS: {'desc': 'Insufficient access'}$", ['uldap.py.* in modify'], 53721),
@@ -179,7 +180,7 @@ COMMON_EXCEPTIONS = (
     # E('univention.admin.uexceptions.permissionDenied: Can not modify lock time of .*', ['in sync_to_ucs']),
     E(r'^(univention\.admin\.uexceptions\.)?noObject:.*', ['__update_membership', 'sync_to_ucs', 'get_ucs_object']),
     # E('^ldapError: No such object', ['in _create']),
-    # E(r"^PAM.error: \('Authentication failure', 7\)", [re.escape('<string>')]),
+    E(r"^PAM.error: \('Authentication failure', 7\)", [re.escape('<string>')]),
     # E(r'^univention.lib.umc.Forbidden: 403 on .* \(command/join/scripts/query\):.*', [re.escape('<string>')]),
     # E('^ldapError: Invalid syntax: univentionLDAPACLActive: value #0 invalid per syntax', ['_create']),
     # E('^ldapError: Invalid syntax: univentionLDAPSchemaActive: value #0 invalid per syntax', ['_create']),
@@ -208,9 +209,19 @@ COMMON_EXCEPTIONS = (
     #     'univention-directory-listener/system/app_attributes.py',
     # ], (53290, 53862)),
     # E("AttributeError: 'ConfigRegistry' object has no attribute '_walk'", ['univention-directory-listener/system/nfs-shares.py'], (53291, 53862)),
-    # E("AttributeError: 'module' object has no attribute 'localization'", ['univention-directory-listener/system/app_attributes.py', 'system/portal_groups.py'], 53862),
-    # E("ImportError: cannot import name localization", ['univention-directory-listener/system/app_attributes.py'], 53862),
-    E("ConnectionRefusedError: \\[Errno 111\\] Connection refused", ['univention-self-service-invitation'], 53670),
+    E("AttributeError: 'module' object has no attribute 'localization'", ['univention-directory-listener/system/app_attributes.py', 'system/portal_groups.py'], 53862),
+    E("ImportError: cannot import name localization", ['univention-directory-listener/system/app_attributes.py'], 53862),
+    E("AttributeError: partially initialized module 'univention.admin' has no attribute 'localization'", ['univention-directory-listener/system'], 53862),
+    E("AttributeError: partially initialized module 'univention.admin' has no attribute 'handlers'", ['ucsschool/lib/models/']),
+    E("AttributeError: module 'lib' has no attribute 'X509_V_FLAG_CB_ISSUER_CHECK'", ['univention-directory-listener/system'], 53862),
+    E("ImportError: cannot import name '_debug' from 'univention'", ['univention-directory-listener/system/'], 53862),
+    E("ImportError: cannot import name '_psutil_linux' from 'psutil'", ['univention-directory-listener/system/'], 53862),
+    E("ImportError: No module named '_gdbm', please install the python3-gdbm package", ['univention-directory-listener/system/'], 53862),
+    E("ModuleNotFoundError: No module named 'apt_pkg'", ['univention-directory-listener/system/'], 53862),
+    E("ModuleNotFoundError: No module named '_gdbm'", ['univention-directory-listener/system/', 'gnu.py'], 53862),
+    E("ModuleNotFoundError: No module named '_ldap'", ['univention-directory-listener/system/'], 53862),
+    E("ModuleNotFoundError: No module named 'ldb'", ['univention-directory-listener/system/'], 53862),
+    E("ConnectionRefusedError: \\[Errno 111\\] Connection refused", ['univention-self-service-invitation', 'urllib/request.py'], 53670),
     E("ConnectionRefusedError: \\[Errno 111\\] Connection refused", ['univention/lib/umc.py.*in send'], 53670),
     E("univention.lib.umc.ConnectionError: .*Could not send request.*Connection refused", ['univention-self-service-invitation'], 53670),
     E("ssl.SSLCertVerificationError.*self.signed certificate in certificate chain", ['univention/lib/umc.py.*in send'], 53670),
@@ -221,8 +232,18 @@ COMMON_EXCEPTIONS = (
     # # during UCS 5.0-x-errata updates
     # E(r"TypeError: __init__\(\) got an unexpected keyword argument 'cli_enabled'", ['_register_app'], 54584),
     # E(r"FileNotFoundError: \[Errno 2\] No such file or directory: '/usr/share/univention-management-console/oidc/oidc.json'", ['server.py'], 49006),
+    E(r"FileNotFoundError: \[Errno 2\] No such file or directory: '/usr/share/univention-portal/portals.json'", ['/usr/sbin/univention-portal-server']),
+    E('ImportError: No module named univention.debug', ['/usr/sbin/univention-management-console-module']),
+    E('pkg_resources.VersionConflict:.*univention-management-console'),
+    E('pkg_resources.DistributionNotFound:.*univention-management-console'),
+    E(r"FileNotFoundError: \[Errno 2\] No such file or directory: '/tmp/.*", ['/tempfile.py.*in __del__']),
+    E(r"univention.lib.umc.ConnectionError: \('Could not send request.', RemoteDisconnected\('Remote end closed connection without response'\)\)", ['univention-self-service-invitation'], 58380),
+    E("http.client.RemoteDisconnected: Remote end closed connection without response", ['/univention/lib/umc.py'], 58380),
+    E(r"...\[truncated \d+ chars\]...", ['univention-self-service-invitation'], 58380),
+    E("KeyError: 'Cookie'", ['univention-self-service-invitation'], 58380),
 
     # # updater test cases:
+    E('EOFError: EOF when reading a line', ['scripts/upgrade.py']),
     E('urllib.error.URLError: .*', ['updater/tools.py.*in access']),
     E('urllib.error.HTTPError: .*', ['updater/tools.py.*in access']),
     E('ConfigurationError: Configuration error: host is unresolvable'),
@@ -234,14 +255,16 @@ COMMON_EXCEPTIONS = (
     E('socket.timeout: timed out'),
     E('TimeoutError: timed out'),
     E(r'socket.gaierror: \[Errno \-2\] Name or service not known'),
-    # E('ConfigurationError: Configuration error: Temporary failure in name resolution', ['in access']),
-    # E(r'socket.gaierror: \[Errno \-3\] Temporary failure in name resolution', ['urllib/request.py']),
+    E('ConfigurationError: Configuration error: Temporary failure in name resolution', ['in access']),
+    E(r"socket.gaierror: \[Errno \-3\] Temporary failure in name resolution", ['urllib/request.py']),
     # # 10_ldap/listener_module_testpy
     E('MyTestException: .*'),
     E('univention.management.console.modules.ucstest.ThreadedError'),  # 60_umc/17_traceback_handling.py
     # # various test cases:
     E('psycopg2.OperationalError: connection to server at "localhost".* failed: Connection refused', ['passwordreset/tokendb.py']),  # 83_self_service/13_test_postgresql_connection_loss.py
     E('psycopg2.OperationalError: SSL connection has been closed unexpectedly', ['passwordreset/tokendb.py']),  # 83_self_service/13_test_postgresql_connection_loss.py
+    E('psycopg2.OperationalError: SSL-Verbindung wurde unerwartet geschlossen', ['passwordreset/tokendb.py']),  # 83_self_service/13_test_postgresql_connection_loss.py
+    E('psycopg2.OperationalError: Verbindung zum Server auf .*localhost.* fehlgeschlagen: Verbindungsaufbau abgelehnt', ['passwordreset/tokendb.py']),  # 83_self_service/13_test_postgresql_connection_loss.py
     # E('AssertionError: .*contain.*traceback.*', ['01_var_log_tracebacks']),
     E('^(univention.management.console.modules.ucstest.)?NonThreadedError$'),
     E(r'^(ldap\.)?INVALID_SYNTAX: .*ABCDEFGHIJKLMNOPQRSTUVWXYZ.*', ['sync_from_ucs']),
@@ -328,7 +351,7 @@ COMMON_EXCEPTIONS = (
     # E('^NoObject: No object found at DN .*', ['univention-portal-server.*in refresh']),
     # E(r"^OSError\: \[Errno 2\].*\/var\/run\/univention-management-console\/.*\.socket"),
     # E(r'ldapError\:\ Type\ or\ value\ exists\:\ univentionPortalEntryLink\:\ value\ \#0\ provided\ more\ than\ once', None, 51808),
-    # E(r"noLock\: .*The attribute \'sid\' could not get locked\.", ['getMachineSid', '__generate_group_sid'], 44294),
+    E(r"noLock\: .*The attribute \'sid\' could not get locked\.", ['getMachineSid', '__generate_group_sid', 'groups/group.*in __allocate_rid'], 44294),
     # E(r'^ImportError\: No module named debhelper', [r'univention\/config_registry\/handler\.py'], 51815),
     # E(r'^NO\_SUCH\_OBJECT\:.*users.*', ['password_sync_s4_to_ucs'], 50279),
     # E(re.escape("Exception: Modifying blog entry failed: 1: E: Daemon died."), [], 45787),
@@ -347,24 +370,35 @@ COMMON_EXCEPTIONS = (
     E('ldap.ALREADY_EXISTS.*already set via primaryGroupID', ['in sync_from_ucs'], 53278),
     # E('ldap.NOT_ALLOWED_ON_NONLEAF:.*Unable to delete a non-leaf node .*it has .* child', ['in delete_in_s4'], 53278),
     # E('univention.admin.uexceptions.valueError: The domain part of the primary mail address is not in list of configured mail domains:', ['in sync_to_ucs'], 53277),
+    E('univention.admin.uexceptions.mailAddressUsed: The mail address is already in use:', ['in sync_to_ucs']),
+    E("univention.admin.uexceptions.noLock: Could not acquire lock: The attribute 'mailPrimaryAddress' could not get locked.", ['in _ldap_pre_ready']),
+    E('univention.admin.uexceptions.groupNameAlreadyUsed: The groupname is already in use as groupname or as username: Users.', ['in sync_to_ucs']),
+    E('univention.admin.uexceptions.groupNameAlreadyUsed: The groupname is already in use as groupname or as username: Domain Controllers.', ['in sync_to_ucs']),
+    E('univention.admin.uexceptions.groupNameAlreadyUsed: The groupname is already in use as groupname or as username: IIS_IUSRS.', ['in sync_to_ucs']),
+    E("univention.admin.uexceptions.noLock: Could not acquire lock: The attribute 'groupName' could not get locked.", ['in _ldap_pre_ready']),
     # E(r"subprocess.CalledProcessError: Command '\('rndc', 'reconfig'\)' returned non-zero exit status 1", ['univention-fix-ucr-dns'], 53332),
     # E(r"ldap.NO_SUCH_OBJECT: .*objectclass: Cannot add cn=(user|machine),cn=\{[0-9a-f-]+\},cn=policies,cn=system,DC=.*parent does not exist", ['in sync_from_ucs'], 53334),
-    # E("TypeError: 'NoneType' object is not subscriptable", ['primary_group_sync_to_ucs', 'add_primary_group_to_addlist'], 53276),
+    E("TypeError: 'NoneType' object is not subscriptable", ['primary_group_sync_to_ucs', 'add_primary_group_to_addlist'], 53276),
     # E("CONSTRAINT_VIOLATION: .*Failed to re-index objectSid in .*unique index violation on objectSid", ['sync_from_ucs'], (53720, 53752)),
     # E('ldap.REFERRAL:.*', ['uldap.py'], 53721),
-    # E('INSUFFICIENT_ACCESS:.*', ['in password_sync_s4_to_ucs'], 53721),
+    E('INSUFFICIENT_ACCESS:.*', ['in password_sync_s4_to_ucs'], 53721),
     # E("ModuleNotFoundError: No module named 'univention.config_registry'", ['/usr/sbin/univention-config-registry'], 53765),
     # E("AttributeError: module 'univention.admin.syntax' has no attribute 'UMCMessageCatalogFilename_and_GNUMessageCatalog'", ['_unregister_app', 'import_hook_files', 'pupilgroups.py'], 53754),
     # E("AttributeError: module 'univention.admin.syntax' has no attribute 'emailAddressThatMayEndWithADot'", ['_update_modules', '/usr/sbin/univention-management-console-server', 'forward_zone.py'], 55590),
     # E('univention.admin.uexceptions.noObject: uid=.*', ['connector/ad/.*set_userPrincipalName_from_ucr'], 53769),
     E('ldap.TYPE_OR_VALUE_EXISTS:.*SINGLE-VALUE attribute description.*specified more than once', ['sync_from_ucs'], 52801),
     E('univention.admin.uexceptions.wrongObjectType: .*relativeDomainName=.* is not recognized as dns/txt_record.', ['ucs_txt_record_create'], 53425),
-    # E(r"ldap.TYPE_OR_VALUE_EXISTS: \{'desc': 'Type or value exists', 'info': 'modify\/add: uniqueMember: value \#\d already exists'\}", ['object_memberships_sync_to_ucs'], 54590),
+    E(r"univention.admin.uexceptions.ldapError: LDAP Error: Type or value exists: modify/add: uniqueMember: value \#\d already exists.", ['group_members_sync_to_ucs'], 54590),
+    E(r"ldap.TYPE_OR_VALUE_EXISTS: \{'desc': 'Type or value exists', 'info': 'modify\/add: uniqueMember: value \#\d already exists'\}", ['object_memberships_sync_to_ucs'], 54590),
+    E('^ldap.TYPE_OR_VALUE_EXISTS:.*modify/add: uniqueMember: value', ['univention/admin/uldap.py.*in modify']),
+    E('^ldap.INSUFFICIENT_ACCESS:.*Insufficient access', ['univention/admin/uldap.py.*in modify']),
+    E('^AssertionError: Authentisierung ist fehlgeschlagen. Bitte melden Sie sich erneut an. == Ungültiger Benutzername oder Passwort.'),
     # # Tracebacks caused by specific UCS@school bugs:
     # E(r"_ldb.LdbError: \(1, 'LDAP client internal error: NT_STATUS_INVALID_PARAMETER'\)", ['univention-samba4-site-tool.py'], 54592),
     # E(r"AssertionError: Attribute \(username\) is parsed wrong as.*", ['103_ucsschool_smbstatus_parser.py'], 54591),
     # E(r"optparse.OptionConflictError: option.*authentication-file", ['univention-samba4-site-tool.py'], 55082),
     E(r"univention.office365.microsoft.exceptions.core_exceptions.MSGraphError"),  # office365 product tests deliberately creates these errors
+    # E(r'.*', ['File "/usr/share/ucs-test/']),
 )
 
 
@@ -379,7 +413,7 @@ def test_appcenter():
 """)
     fd.name = '/var/log/univention/appcenter.log'
     out = io.StringIO('w')
-    assert not main([fd], out=out)
+    assert not main([fd], out=out, err=out)
     assert '''Traceback (most recent call last):
   File "/usr/sbin/univention-pkgdb-scan", line 37, in <module>
     univention.pkgdb.main()
@@ -397,7 +431,7 @@ foo = bar
 Exception: foo
 bar""")
     out = io.StringIO('w')
-    assert not main([fd], out=out)
+    assert not main([fd], out=out, err=out)
     assert """Traceback (most recent call last):
   File "<stdin>", line 8, in <module>
   File "xyz", line 8, in bar
@@ -414,7 +448,7 @@ def test_journald_indented():
     Exception: foo
 bar""")
     out = io.StringIO('w')
-    assert not main([fd], out=out)
+    assert not main([fd], out=out, err=out)
     assert """Traceback (most recent call last):
   File "<stdin>", line 8, in <module>
   File "xyz", line 8, in bar
